imblearn.under_sampling.TomekLinks
==================================

.. currentmodule:: imblearn.under_sampling

.. autoclass:: TomekLinks

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~TomekLinks.__init__
      ~TomekLinks.fit
      ~TomekLinks.fit_sample
      ~TomekLinks.get_params
      ~TomekLinks.is_tomek
      ~TomekLinks.sample
      ~TomekLinks.set_params
   
   

   
   
   